@@ -1,5 +1,8 @@
+import os
 import structlog
+import logging
 import sys
+from operator import attrgetter
 
 
 def get_logger() -> structlog.stdlib.BoundLogger:
@@ -9,12 +12,16 @@ def get_logger() -> structlog.stdlib.BoundLogger:
         structlog.processors.TimeStamper(fmt="%Y-%m-%d %H:%M.%S"),
         structlog.processors.StackInfoRenderer(),
     ]
+    level = attrgetter(os.getenv("LOG_LEVEL", "INFO"))(logging)
     if sys.stderr.isatty():
-        # Pretty printing when we run in a terminal session.
+        # Pretty printing when we run in a terminal session / in local development env.
         # Automatically prints pretty tracebacks when "rich" is installed
         processors = shared_processors + [structlog.dev.ConsoleRenderer()]
         structlog.configure(
-            processors=processors, context_class=dict, cache_logger_on_first_use=True
+            processors=processors,
+            context_class=dict,
+            cache_logger_on_first_use=True,
+            wrapper_class=structlog.make_filtering_bound_logger(level),
         )
     else:
         # Print JSON when we run, e.g., in a Docker container.
@@ -25,6 +32,7 @@ def get_logger() -> structlog.stdlib.BoundLogger:
         ]
         structlog.configure(
             processors,
+            wrapper_class=structlog.make_filtering_bound_logger(level),
             cache_logger_on_first_use=True,
         )
     return structlog.get_logger()
